import requests
import logging
from notifier.

logger = logging.getLogger("notif")


class CGSmsClient:
    sub_account = "jefcolbi@gmail.com"
    sub_account_pass = "cheapglobalsms01$"

    def __init__(self, number, text):
        pass

    @classmethod
    def send(cls, number: str, text: str):
        logger.info(f"Sending SMS {text} TO {number}")
        if not number.startswith("+237"):
            number = f"+237{number}"
        params = {
            "sub_account": cls.sub_account,
            "sub_account_pass": cls.sub_account_pass,
            "action": "send_sms",
            "message": text,
            "recipients": number,
        }
        res = requests.get("http://cheapglobalsms.com/api_v1", params=params)
        # print(res.content)
        # print(res.json())


if __name__ == "__main__":
    CGSmsClient.send("693480847", "Cava ma tigresse")



from django.test import TestCase
from django.contrib.auth import  get_user_model
from magic_notifier.notifier import notify
from django.test.utils import override_settings
from django.core import mail

User = get_user_model()


#@override_settings(EMAIL_BACKEND='django.core.mail.backends.smtp.EmailBackend')
class EmailTestCase(TestCase):
    """Class to test emails sending"""

    def test_simple_direct_email(self):
        user = User(email="jefcolbi@gmail.com", username="jefcolbi")

        subject = "Test magic notifier"
        notify(["email"], subject, [user], final_message="Super si tu reçois ce mail Jef")

        self.assertGreater(len(mail.outbox), 0)
        first_message = mail.outbox[0]
        self.assertEqual(first_message.to, [user.email])
        self.assertEqual(first_message.subject, subject)



from __future__ import absolute_import, unicode_literals
from celery import shared_task

import requests
from django.conf import settings
from django.shortcuts import reverse
import traceback
from urllib.parse import quote
import os
import logging



from django.core.mail import get_connection, send_mail
from django.core.mail.message import EmailMessage
from django.core.mail import EmailMultiAlternatives
from django.template.loader import render_to_string
from threading import Thread
from django.conf import settings
import traceback
import re
import unidecode
import logging
from django.utils.translation import gettext as _
from django.utils.translation import activate
from .utils import import_class
from typing import Optional

logger = logging.getLogger("notifier")


class Emailer:
    def __init__(
        self,
        subject: str,
        receivers: list,
        template: Optional[str],
        context: dict,
        smtp_account: str='default',
        final_message: str = None,
        **kwargs,
    ):
        from magic_notifier.settings import NOTIFIER_SMTP
        self.email_settings:dict = NOTIFIER_SMTP[smtp_account]
        self.email_client = import_class(self.email_settings["CLIENT"])

        self.connection = self.email_client.get_connection(self.email_settings)
        self.subject: str = subject
        self.receivers: list = receivers
        self.template: str = template
        self.context: dict = context if context else {}
        self.final_message = final_message
        self.threaded: bool = kwargs.get("threaded", False)

    def send(self):
        if self.threaded:
            t = Thread(target=self._send)
            t.setDaemon(True)
            t.start()
        else:
            self._send()

    def _send(self):
        try:
            logger.info(f"sending emails to {self.receivers}")
            for user in self.receivers:
                # activate(user.settings.lang)

                ctx = self.context.copy()
                ctx["user"] = user
                logger.info(f"===== user name {user.username}")
                logger.info(ctx)

                if self.template:
                    html_content = render_to_string(
                        "{}/email.html".format(self.template), ctx
                    )  # render with dynamic value
                    logger.info(html_content)

                    text_content = render_to_string(
                    "{}/email.txt".format(self.template), ctx
                    )  # render with dynamic value
                    logger.info(text_content)
                else:
                    html_content = text_content = self.final_message

                msg = EmailMultiAlternatives(
                    self.subject,
                    text_content,
                    self.email_settings["FROM"],
                    [user.email],
                    connection=self.connection,
                )
                msg.attach_alternative(html_content, "text/html")
                msg.send()
        except:
            logger.error(traceback.format_exc())
            print(traceback.format_exc())


if __name__ == "__main__":
    emailer = Emailer("Reset code", ["jefcolbi@gmail.com"], "reset", {}, "account")
    emailer.send()



from magic_notifier.emailer import Emailer
from magic_notifier.smsers import ExternalSMS
from magic_notifier.pusher import Pusher
import logging
import traceback
from magic_notifier.settings import NOTIFIER_THREADED

logger = logging.getLogger("notifier")


def notify(
    vias: list,
    subject: str = None,
    receivers: list = None,
    template: str = None,
    context: dict = {},
    final_message: str = None,
    smtp_account: str = 'default',
    threaded: bool = None,
):
    logger.info(f"Sending {subject} to {receivers} via {vias}")
    threaded = threaded if threaded is not None else NOTIFIER_THREADED

    # TODO: add support to receivers = "admins", "staff", "all", "all-staff", "all-admins"

    for via in vias:
        try:
            if via == "email":
                em = Emailer(
                    subject,
                    receivers,
                    template,
                    context,
                    smtp_account,
                    threaded=threaded,
                    final_message=final_message,
                )
                em.send()

            elif via == "sms":
                ex_sms = ExternalSMS(receivers, template, context, threaded=threaded)
                ex_sms.send()

            elif via == "push":
                pusher = Pusher(
                    subject, receivers, template, context, threaded=threaded
                )
                pusher.send()

            else:
                logger.error(f"Unknown sending method {via}")

        except:
            logger.error(traceback.format_exc())



from threading import Thread
from django.template.loader import render_to_string
import logging
import traceback
from .settings import NOTIFIER_SMS_CLIENT
import importlib

logger = logging.getLogger("notifier")


class ExternalSMS:
    def __init__(self, receivers: list, template: str, context: dict, **kwargs):
        self.receivers: list = receivers
        self.template: str = template
        self.context: dict = context
        self.threaded: bool = kwargs.get("threaded", False)

        module_name, class_name = NOTIFIER_SMS_CLIENT.rsplit(".", 1)
        module = importlib.import_module(module_name)
        assert hasattr(module, class_name), "class {} is not in {}".format(class_name, module_name)
        self.client_class = getattr(module, class_name)

    def send(self):
        if self.threaded:
            t = Thread(target=self._send)
            t.setDaemon(True)
            t.start()
        else:
            self._send()

    def _send(self):
        try:
            for rec in self.receivers:
                ctx = self.context.copy()
                ctx["user"] = rec
                sms_content = render_to_string("{}/sms.txt".format(self.template), ctx)

                self.client_class.send(rec.number, sms_content)
        except:
            logger.error(traceback.format_exc())


if __name__ == "__main__":
    pass
